clc;clear;close all;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% GECAD GECCO and CEC 2021 Competition: Evolutionary Computation in Uncertain Environments: A Smart Grid Application
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
addpath('functions') %Necessary functions to run the algorithms (encrypted)
tTotalTime=tic; %lets track total computational time
global No_solutions ;
Select_testbed=2; 
%Testbed 1: Optimal bidding in local energy markets
%Testbed 2: Flexibility management of home appliances to support DSO requests

Select_Algorithm=17;
%1: HyDE-DF algorithm (test algorithm)
%2: Your algorithm 
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Load MH parameters (e.g., get MH parameters from DEparameters.m file)
switch Select_Algorithm
    case 1
        addpath('HyDE-DF')
        algorithm='HyDEDF'; %'The participants should include their algorithm here'
        DEparameters %Function defined by the participa nt
        No_solutions=deParameters.I_NP; %Notice that some algorithms are limited to one individual
     case 17
        addpath('GSK-IF')
        algorithm='GSK-IF'; %'The participants should include their algorithm here'
        GSKIFparameters %Function defined by the participant
        if Select_testbed==1            
            parameters.max_nfes = 10000;  
            parameters.update_K = 0.8;             
            parameters.KR_pool = [0.45 0.1 0.3 0.2]; 
            parameters.poww = 8 ;
        else            
            parameters.max_nfes = 100000;
            parameters.update_K = 0.95;
            parameters.KR_pool = [0.3 0.1 0.1 0.2];
            parameters.poww =7;
        end                      
    otherwise
        fprintf(1,'No algorithm selected\n');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Load Data base
noRuns=20; %this can be changed but final results should be based on 20 trials
DB=Select_testbed;
% 1: Case study testbed 1
% 2: Case study testbed 2

[caseStudyData, DB_name]=callDatabase(DB);

%% Label of the algorithm and the case study
Tag.algorithm=algorithm;
Tag.DB=DB_name;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Set other parameters
otherParameters =setOtherParameters(caseStudyData,No_solutions,Select_testbed);
otherParameters.one=setOtherParameters(caseStudyData,1,Select_testbed);
% %% Set lower/upper bounds of variables
[lowerB,upperB] = setVariablesBounds(caseStudyData,otherParameters, Select_testbed);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Call the MH for optimizationclear
ResDB=struc([]);
for iRuns=1:noRuns %Number of trails
    tOpt=tic;
    rand('state',sum(noRuns*100*clock))% ensure stochastic indpt trials
    
    otherParameters.iRuns=iRuns;
%    rand('state',otherParameters.iRuns);
    switch Select_Algorithm
        case 1
            [ResDB(iRuns).Fit_and_p, ...
                ResDB(iRuns).sol, ...
                ResDB(iRuns).fitVector]= ...
                HyDE(deParameters,caseStudyData,otherParameters,lowerB,upperB);        
            case 17
                [ResDB(iRuns).Fit_and_p, ...
                ResDB(iRuns).sol, ...
                ResDB(iRuns).fitVector]= ...                    
                GSKIF(parameters,caseStudyData,otherParameters,lowerB,upperB);           
    end 
    
    ResDB(iRuns).tOpt=toc(tOpt); % time of each trial
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    %% Save the results and stats
    Save_results
end
tTotalTime=toc(tTotalTime); %Total time
%% End of MH Optimization